.. _eerstekamer:

BRIEF EERSTE KAMER
##################
  

  Heerhugowaard, 21-02-2017

Geachte redactie,fractie,voorzitter,

ik wil U met deze brief op de hoogte brengen dat de Eerste Kamer over het volgende is geinformeerd. namelijk dat de zorg die men met de WvGGZ wenst te leveren niet het toedienen van medicatie betreft maar het toedienen van gif.

DODELIJK

Antipsychotica zijn schadelijk, ze veroorzaken hersenweefselverlies, Dit is aangetoond door haldol 2 jaar op makaken aapjes te testen en daarna de hersenen te meten. 8 tot 11% hersenweefselverlies in een periode van 2 jaar toont dat het hier schadelijke stof betreft, zie (1).

Antipsychotica zijn niet alleen schadelijk ze zijn ook dodelijk, toedienen brengt de kans op sterven, zie (2). Bijv. Clozapine kan de volgende potentieel dodelijk aandoeningen veroorzaken:

*    Neutropenia (tekort witte bloedcellen)
*    Myocarditis (ontsteking hartspier)
*    Cardiomyopathy (ook hartspier)
*    Hypotension (lage bloeddruk)
*    Bradycardia (trage hartslag)
*    Syncope (flauwvallen)
*    Cardiac arrest (hartstilstand)
*    Neuroleptic Malignant Syndrome (NMS)
*    Constipation (dikke darm verstopping)
*    Intestinal Obstruction (darm problemen)
*    Fecal Impaction (vastzittend stront)
*    Paralytic Ileus (ook voedsel vastzittend in de darm)

Los van bijwerkingen die dodelijk kunnen zijn, kan dit medicijn ook in dodelijk hoeveelheid toegediend worden. 12,5 mg is als dodelijk genoteerd, standaard OD is 2.5 gram, sommige overleven boven de 4 gram, zie (3)

(F)ACT

Is men al aan het mishandelen door gif toe te dienen, het nalaten de noodzakelijke verpleging te leveren maakt de mishandeling levensgevaarlijk:

1) Off-label toedienen.

    Off-label toedienen houd in dat er of buiten de toegestaande bloedspiegels toegedient word of dat het medicijnen voor een andere ziekte word toegedient dan waarvoor hij getest is. Dient men hogere waardes toe dan toegestaan dan is men aan het vergiftigen. Dat een arts heden ten dage uberhaupt Off-label mag toedienen is al belachelijk (want per definitie vergiftiging).

2) Onder de ondergrens toedienen.

    Deze dodelijke stoffen hebben boven EN onder grenzen wat betreft bloedspiegels, depletie (het ontbreken van stoffen) is ook levensbedreigend.

3) Ontkennen dat men dodelijke stoffen toedient.

    Als een arts ontkent dat hij dodelijke stoffen toedient, dient hij MEER toe van die stof als de patient onstabiel word. I.p.v. de medicijnen af te bouwen, dient hij meer toe. De horror voor het slachtoffer dat in een toestand van vergiftiging meer gif krijgt toegedient.

4) Bloedspiegel van een medicijn niet meten.

    Als een arts niet de bloedspiegels van een medicijn meet is hij niet op de hoogte van de toestand van de patient en kan dus ook geen goed oordeel vellen over het ziektebeeld van de patient. De arts probeert maar wat.

5) Symptomen van een vergiftiging niet (willen) zien.

    Als een arts al dodelijk stoffen toedient en dat zelf niet wil erkennen is het voor hem ook onmogelijk om symptomen die ontstaan door het toedienen van dodelijke stoffen aan de dodelijke stoffen toe te kennen. Als een arts niet symptomen van vergiftiging erkent, komt de patient in een neerwaartse spiraal terecht waarbij zijn toestand met de dag verslechterd.

6) Eerst een afspraak maken voordat je een crisis kan melden,in het weekend en avonduren niet beschikbaar.

    De (F)ACT teams die de toediening van dodelijke stoffen verantwoord zouden moeten doen, zijn er in het weekend niet, in de avonduren niet, laten je een afspraak maken dat je een crisis mag melden, doen alles om maar niet te hoefen reageren om hulproepen van hun slachtoffers. Het niet aanwezig zijn van de noodzakelijke verpleging als met met dodelijke stoffen behandelt brengt wanhoop en paniek bij de slachtoffers die voor hun leven moeten vrezen.

7) Pas zorgverlenen als de ellende al gebeurd is.

    Men werkt met het principe van “stepped-care”, geschakelde zorg, waarbij men meer zorg levert naar gelang de toestand van het slachtoffer daar omvraagt. Dit maakt dat men altijd eerst de ellende laat gebeuren, waarna men pas extra zorg inschakelt. Wat men hier bezigt is “budget overschot is winst”, de zorg die men niet levert kan men als winst inboeken.

8) Symptomen zelf bijhouden.

    De controle op de geleverde verpleging is zo slecht dat het aan een slachtoffer is om bij te houden hoe het met toename/afname van symptomen gaat. Het slachtoffer is echter helemaal niet in staat om symptomen bij te houden, het is aan de mantelzorger om te constateren dat een slachtoffer in een toestand van vergiftiging verkeerd.

9) Oordeel “geen crisis”

    Het toedienen van gif onder onverantwoorde omstandigheden maakt dat het slachtoffer in levensbedreigende situaties terecht komt. Deze door de “zorg” gegenereerde levensbedreiging is waar het slachtoffer mee te maken krijgt. Wel symptomen van dodelijke aandoeningen dan oordelen dat er geen opname nodig is, maakt dat noodzakelijke medische hulp hierbij word ontzegt.

10) Behandelplan niet ingevuld.

    Bij de behandeling door de GGZ word er zo min mogelijk aan verplichtingen opgeschreven in het behandelplan zodat er ook geen claims tot prestatie gemaakt kunnen worden.

CONCLUSIE

| De WvGGZ spreekt over medicatie die, naar de definitie omschreven in de geneesmiddelenwet, geen schade kunnen, maar in de behandeling die de GGZ levert dient men gif toe en niet medicatie. Door gif toe te dienen in plaats van medicijnen pleegt men mishandeling zoals omschreven in het Wetboek van Strafrecht.
| De WvGGZ kunt u niet aannemen, want in de praktijk word hij gebruikt om te mishandelen en niet te behandelen.
| Deze wet, noch de BOPZ, bieden legitimering voor het toedienen van gif.
| De gif toedieningen die men pleegt zijn strafbaar en dienen vervolgt te worden.

URLS

    The influence of chronic exposure to antipsychotic medications on brain size before and after tissue fixation: a comparison of haloperidol and olanzapine in macaque monkeys 

| https://www.ncbi.nlm.nih.gov/pubmed/15756305
| http://pythonhosted.org/evrm/txt/clozapine.html#clozapine
| http://pythonhosted.org/evrm/txt/toxic.html

CONTACT

| Bartholomeus Henricus Julius (Bart) Thate - evrm, teksten
| botfather on #dunkbots http://irc.freenode.net
| email is bthate@dds.nl, thatebart@gmail.com
